==> nuclide-0.353.0.tgz: package/modules/atom-ide-ui/pkg/atom-ide-code-format/lib/main.js <==
"use strict";

function _createPackage() {
  const data = _interopRequireDefault(require("../../../../nuclide-commons-atom/createPackage"));

  _createPackage = function () {
    return data;
  };

  return data;
}

function _CodeFormatManager() {
  const data = _interopRequireDefault(require("./CodeFormatManager"));

  _CodeFormatManager = function () {
    return data;
  };

  return data;
}

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Copyright (c) 2017-present, Facebook, Inc.
 * All rights reserved.
 *
 * This source code is licensed under the BSD-style license found in the
 * LICENSE file in the root directory of this source tree. An additional grant
 * of patent rights can be found in the PATENTS file in the same directory.
 *
 *  strict-local
 * @format
 */
class Activation {
  constructor() {
    this.codeFormatManager = new (_CodeFormatManager().default)();
  }

  consumeLegacyProvider(provider) {
    // Legacy providers used `selector` / `inclusionPriority`.
    provider.grammarScopes = provider.grammarScopes || (provider.selector != null ? provider.selector.split(', ') : null);
    provider.priority = provider.priority != null ? provider.priority : // $FlowFixMe(>=0.68.0) Flow suppress (T27187857)
    provider.inclusionPriority != null ? provider.inclusionPriority : 0;

    if (provider.formatCode) {
      return this.consumeRangeProvider(provider);
    } else if (provider.formatEntireFile) {
      return this.consumeFileProvider(provider);
    } else if (provider.formatAtPosition) {
      return this.consumeOnTypeProvider(provider);
    } else if (provider.formatOnSave) {
      return this.consumeOnSaveProvider(provider);
    }

    throw new Error('Invalid code format provider');
  }

  consumeRangeProvider(provider) {
    return this.codeFormatManager.addRangeProvider(provider);
  }

  consumeFileProvider(provider) {
    return this.codeFormatManager.addFileProvider(provider);
  }

  consumeOnTypeProvider(provider) {
    return this.codeFormatManager.addOnTypeProvider(provider);
  }

  consumeOnSaveProvider(provider) {
    return this.codeFormatManager.addOnSaveProvider(provider);
  }

  consumeBusySignal(busySignalService) {
    return this.codeFormatManager.consumeBusySignal(busySignalService);
  }

  dispose() {
    this.codeFormatManager.dispose();
  }

}

(0, _createPackage().default)(module.exports, Activation);

==> nuclide-0.360.0.tgz: package/modules/atom-ide-ui/pkg/atom-ide-code-format/lib/main.js <==
"use strict";

function _createPackage() {
  const data = _interopRequireDefault(require("../../../../nuclide-commons-atom/createPackage"));

  _createPackage = function () {
    return data;
  };

  return data;
}

function _CodeFormatManager() {
  const data = _interopRequireDefault(require("./CodeFormatManager"));

  _CodeFormatManager = function () {
    return data;
  };

  return data;
}

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Copyright (c) 2017-present, Facebook, Inc.
 * All rights reserved.
 *
 * This source code is licensed under the BSD-style license found in the
 * LICENSE file in the root directory of this source tree. An additional grant
 * of patent rights can be found in the PATENTS file in the same directory.
 *
 *  strict-local
 * @format
 */
class Activation {
  constructor() {
    this.codeFormatManager = new (_CodeFormatManager().default)();
  }

  consumeLegacyProvider(provider) {
    // Legacy providers used `selector` / `inclusionPriority`.
    // $FlowIgnore legacy API compatability.
    provider.grammarScopes = provider.grammarScopes || ( // $FlowIgnore
    provider.selector != null ? provider.selector.split(', ') : null);
    provider.priority = provider.priority != null ? provider.priority : // $FlowFixMe(>=0.68.0) Flow suppress (T27187857)
    provider.inclusionPriority != null ? provider.inclusionPriority : 0;

    if (provider.formatCode) {
      return this.consumeRangeProvider(provider);
    } else if (provider.formatEntireFile) {
      return this.consumeFileProvider(provider);
    } else if (provider.formatAtPosition) {
      return this.consumeOnTypeProvider(provider);
    } else if (provider.formatOnSave) {
      return this.consumeOnSaveProvider(provider);
    }

    throw new Error('Invalid code format provider');
  }

  consumeRangeProvider(provider) {
    return this.codeFormatManager.addRangeProvider(provider);
  }

  consumeFileProvider(provider) {
    return this.codeFormatManager.addFileProvider(provider);
  }

  consumeOnTypeProvider(provider) {
    return this.codeFormatManager.addOnTypeProvider(provider);
  }

  consumeOnSaveProvider(provider) {
    return this.codeFormatManager.addOnSaveProvider(provider);
  }

  consumeBusySignal(busySignalService) {
    return this.codeFormatManager.consumeBusySignal(busySignalService);
  }

  dispose() {
    this.codeFormatManager.dispose();
  }

}

(0, _createPackage().default)(module.exports, Activation);
